@@ -1,12 +1,12 @@
 from __future__ import with_statement
 
 from speaklater import _LazyString
-from flask.json import JSONEncoder
-from flask import Flask, render_template, jsonify
+from flask import Flask, render_template, json, jsonify
 from wtforms import TextField, HiddenField, SubmitField
 from wtforms.validators import DataRequired
 from flask_wtf import Form
 from flask_wtf._compat import text_type
+JSONEncoder = json.JSONEncoder
 
 
 def to_unicode(text):
@@ -103,7 +103,7 @@ class TestCase(object):
                                errors=None)
 
             return jsonify(name=None,
-                           errors=form.errors,
+                           #errors=form.errors,
                            success=False)
 
         return app
